==> moodle_1.3.1.orig.tar.gz: moodle/lang/en/calendar.php <==
<?php // $Id: calendar.php,v 1.10 2004/05/21 13:52:29 defacer Exp $

$string['calendar'] = 'Calendar';
$string['calendarheading'] = '$a Calendar';
$string['clickhide'] = 'click to hide';
$string['clickshow'] = 'click to show';
$string['confirmeventdelete'] = 'Are you sure you want to delete this event?';
$string['courseevents'] = 'Course events';
$string['dayview'] = 'Day View';
$string['daywithnoevents'] = 'There are no events this day.';
$string['default'] = 'Default';
$string['deleteevent'] = 'Delete event';
$string['detailedmonthview'] = 'Detailed Month View';
$string['durationminutes'] = 'Duration in minutes';
$string['durationnone'] = 'Without duration';
$string['durationuntil'] = 'Until';
$string['editevent'] = 'Editing event';
$string['errorbeforecoursestart'] = 'Cannot set event before course start date';
$string['errorinvaliddate'] = 'Invalid date';
$string['errorinvalidminutes'] = 'Specify duration in minutes by giving a number between 1 and 999.';
$string['errorinvalidrepeats'] = 'Specify the number of events by giving a number between 1 and 99.';
$string['errornodescription'] = 'Description is required';
$string['errornoeventname'] = 'Name is required';
$string['eventdate'] = 'Date';
$string['eventdescription'] = 'Description';
$string['eventduration'] = 'Duration';
$string['eventendtime'] = 'End time';
$string['eventinstanttime'] = 'Time';
$string['eventkind'] = 'Type of event';
$string['eventname'] = 'Name';
$string['eventrepeat'] = 'Repeats';
$string['eventsfor'] = '$a events';
$string['eventstarttime'] = 'Start time';
$string['eventtime'] = 'Time';
$string['eventview'] = 'Event Details';
$string['expired'] = 'Expired';
$string['explain_lookahead'] = 'This sets the (maximum) number of days in the future that an event has to start in in order to be displayed as an upcoming event. Events that start beyond this will never be displayed as upcoming. Please note that <strong>there is no guarantee</strong> that all events starting in this time frame will be displayed; if there are too many (more than the \"Maximum upcoming events\" preference) then the most distant events will not be shown.';
$string['explain_maxevents'] = 'This sets the maximum number of upcoming events that can be displayed. If you pick a large number here it is possible that upcoming events displays will take up a lot of space on your screen.';
$string['explain_startwday'] = 'Calendar weeks will be shown as starting on the day that you select here.';
$string['explain_timeformat'] = 'You can choose to see times in either 12 or 24 hour format. If you choose \"default\", then the format will be automatically chosen according to the language you use in the site.';
$string['globalevents'] = 'Global events';
$string['gotocalendar'] = 'Go to calendar';
$string['groupevents'] = 'Group events';
$string['hidden'] = 'hidden';
$string['manyevents'] = '$a events';
$string['monthlyview'] = 'Monthly View';
$string['newevent'] = 'New Event';
$string['noupcomingevents'] = 'There are no upcoming events';
$string['oneevent'] = '1 event';
$string['pref_lookahead'] = 'Upcoming events look-ahead';
$string['pref_maxevents'] = 'Maximum upcoming events';
$string['pref_startwday'] = 'First day of week';
$string['pref_timeformat'] = 'Time display format';
$string['preferences'] = 'Preferences';
$string['preferences_available'] = 'Your personal preferences';
$string['repeatnone'] = 'No repeats';
$string['repeatweeksl'] = 'Repeat weekly, creating altogether ';
$string['repeatweeksr'] = 'events';
$string['shown'] = 'shown';
$string['spanningevents'] = 'Events underway';
$string['timeformat_12'] = '12-hour (am/pm)';
$string['timeformat_24'] = '24-hour';
$string['today'] = 'Today';
$string['tomorrow'] = 'Tomorrow';
$string['tt_deleteevent'] = 'Delete event';
$string['tt_editevent'] = 'Edit event';
$string['tt_hidecourse'] = 'Course events are shown (click to hide)';
$string['tt_hideglobal'] = 'Global events are shown (click to hide)';
$string['tt_hidegroups'] = 'Group events are shown (click to hide)';
$string['tt_hideuser'] = 'User events are shown (click to hide)';
$string['tt_showcourse'] = 'Course events are hidden (click to show)';
$string['tt_showglobal'] = 'Global events are hidden (click to show)';
$string['tt_showgroups'] = 'Group events are hidden (click to show)';
$string['tt_showuser'] = 'User events are hidden (click to show)';
$string['typecourse'] = 'Course event';
$string['typegroup'] = 'Group event';
$string['typesite'] = 'Site event';
$string['typeuser'] = 'User event';
$string['upcomingevents'] = 'Upcoming Events';
$string['userevents'] = 'User events';
$string['yesterday'] = 'Yesterday';

$string['sun'] = 'Sun';
$string['mon'] = 'Mon';
$string['tue'] = 'Tue';
$string['wed'] = 'Wed';
$string['thu'] = 'Thu';
$string['fri'] = 'Fri';
$string['sat'] = 'Sat';
$string['sunday'] = 'Sunday';
$string['monday'] = 'Monday';
$string['tuesday'] = 'Tuesday';
$string['wednesday'] = 'Wednesday';
$string['thursday'] = 'Thursday';
$string['friday'] = 'Friday';
$string['saturday'] = 'Saturday';
$string['january'] = 'January';
$string['february'] = 'February';
$string['march'] = 'March';
$string['april'] = 'April';
$string['may'] = 'May';
$string['june'] = 'June';
$string['july'] = 'July';
$string['august'] = 'August';
$string['september'] = 'September';
$string['october'] = 'October';
$string['november'] = 'November';
$string['december'] = 'December';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/en/calendar.php <==
<?php // $Id$

$string['calendar'] = 'Calendar';
$string['calendarheading'] = '$a Calendar';
$string['clickhide'] = 'click to hide';
$string['clickshow'] = 'click to show';
$string['confirmeventdelete'] = 'Are you sure you want to delete this event?';
$string['courseevents'] = 'Course events';
$string['dayview'] = 'Day View';
$string['daywithnoevents'] = 'There are no events this day.';
$string['default'] = 'Default';
$string['deleteevent'] = 'Delete event';
$string['detailedmonthview'] = 'Detailed Month View';
$string['durationminutes'] = 'Duration in minutes';
$string['durationnone'] = 'Without duration';
$string['durationuntil'] = 'Until';
$string['editevent'] = 'Editing event';
$string['errorbeforecoursestart'] = 'Cannot set event before course start date';
$string['errorinvaliddate'] = 'Invalid date';
$string['errorinvalidminutes'] = 'Specify duration in minutes by giving a number between 1 and 999.';
$string['errorinvalidrepeats'] = 'Specify the number of events by giving a number between 1 and 99.';
$string['errornodescription'] = 'Description is required';
$string['errornoeventname'] = 'Name is required';
$string['eventdate'] = 'Date';
$string['eventdescription'] = 'Description';
$string['eventduration'] = 'Duration';
$string['eventendtime'] = 'End time';
$string['eventinstanttime'] = 'Time';
$string['eventkind'] = 'Type of event';
$string['eventname'] = 'Name';
$string['eventrepeat'] = 'Repeats';
$string['eventsfor'] = '$a events';
$string['eventstarttime'] = 'Start time';
$string['eventtime'] = 'Time';
$string['eventview'] = 'Event Details';
$string['expired'] = 'Expired';
$string['explain_lookahead'] = 'This sets the (maximum) number of days in the future that an event has to start in in order to be displayed as an upcoming event. Events that start beyond this will never be displayed as upcoming. Please note that <strong>there is no guarantee</strong> that all events starting in this time frame will be displayed; if there are too many (more than the \"Maximum upcoming events\" preference) then the most distant events will not be shown.';
$string['explain_maxevents'] = 'This sets the maximum number of upcoming events that can be displayed. If you pick a large number here it is possible that upcoming events displays will take up a lot of space on your screen.';
$string['explain_persistflt'] = 'If this is enabled, then Moodle will remember your last event filter settings and automatically restore them each time you login.';
$string['explain_startwday'] = 'Calendar weeks will be shown as starting on the day that you select here.';
$string['explain_timeformat'] = 'You can choose to see times in either 12 or 24 hour format. If you choose \"default\", then the format will be automatically chosen according to the language you use in the site.';
$string['globalevents'] = 'Global events';
$string['gotocalendar'] = 'Go to calendar';
$string['groupevents'] = 'Group events';
$string['hidden'] = 'hidden';
$string['manyevents'] = '$a events';
$string['monthlyview'] = 'Monthly View';
$string['newevent'] = 'New Event';
$string['noupcomingevents'] = 'There are no upcoming events';
$string['oneevent'] = '1 event';
$string['pref_lookahead'] = 'Upcoming events look-ahead';
$string['pref_maxevents'] = 'Maximum upcoming events';
$string['pref_persistflt'] = 'Remember filter settings';
$string['pref_startwday'] = 'First day of week';
$string['pref_timeformat'] = 'Time display format';
$string['preferences'] = 'Preferences';
$string['preferences_available'] = 'Your personal preferences';
$string['repeatnone'] = 'No repeats';
$string['repeatweeksl'] = 'Repeat weekly, creating altogether ';
$string['repeatweeksr'] = 'events';
$string['shown'] = 'shown';
$string['spanningevents'] = 'Events underway';
$string['timeformat_12'] = '12-hour (am/pm)';
$string['timeformat_24'] = '24-hour';
$string['today'] = 'Today';
$string['tomorrow'] = 'Tomorrow';
$string['tt_deleteevent'] = 'Delete event';
$string['tt_editevent'] = 'Edit event';
$string['tt_hidecourse'] = 'Course events are shown (click to hide)';
$string['tt_hideglobal'] = 'Global events are shown (click to hide)';
$string['tt_hidegroups'] = 'Group events are shown (click to hide)';
$string['tt_hideuser'] = 'User events are shown (click to hide)';
$string['tt_showcourse'] = 'Course events are hidden (click to show)';
$string['tt_showglobal'] = 'Global events are hidden (click to show)';
$string['tt_showgroups'] = 'Group events are hidden (click to show)';
$string['tt_showuser'] = 'User events are hidden (click to show)';
$string['typecourse'] = 'Course event';
$string['typegroup'] = 'Group event';
$string['typesite'] = 'Site event';
$string['typeuser'] = 'User event';
$string['upcomingevents'] = 'Upcoming Events';
$string['userevents'] = 'User events';
$string['yesterday'] = 'Yesterday';

$string['sun'] = 'Sun';
$string['mon'] = 'Mon';
$string['tue'] = 'Tue';
$string['wed'] = 'Wed';
$string['thu'] = 'Thu';
$string['fri'] = 'Fri';
$string['sat'] = 'Sat';
$string['sunday'] = 'Sunday';
$string['monday'] = 'Monday';
$string['tuesday'] = 'Tuesday';
$string['wednesday'] = 'Wednesday';
$string['thursday'] = 'Thursday';
$string['friday'] = 'Friday';
$string['saturday'] = 'Saturday';

$string['pref_dstpreset'] = 'Daylight Savings Time';
$string['notusingdst'] = 'Not using DST';
$string['dstpresetname'] = 'Preset name';
$string['dstpresetactivated'] = 'Activation';
$string['dstpresetdeactivated'] = 'Dectivation';
$string['dstpresetadjusttime'] = 'Time adjustment';

$string['explain_dstpresetforced'] = 'The site administrator does not allow users to modify this option.';
$string['explain_dstpreset'] = 'You can select which area to use DST settings for, if any, from the drop-down menu.';
$string['dstdefaultpresetname'] = 'New DST Preset';
$string['nth'] = '{$a}st';
$string['dsthumanreadable'] = 'On the $a->activate_index $a->activate_weekday of each $a->activate_month, move the time $a->offset minutes $a->direction. This change lasts until the $a->deactivate_index $a->deactivate_weekday of $a->deactivate_month.';
$string['dstadjusttime'] = 'Move time';
$string['dstof'] = 'of';
$string['dstat'] = 'at';
$string['dstonthe'] = 'On the';
$string['dstby'] = 'by';
$string['day'] = 'day';
$string['timeforward'] = 'forward';
$string['timerewind'] = 'backwards';
$string['first'] = 'first';
$string['last'] = 'last';
?>
